==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_ja.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=ja
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'リセットする',
	'boxstr_close' => '閉じる',
	'boxstr_current' => '@current@/@total@',
	'boxstr_dialog_title_default' => 'ダイアログボックス',
	'boxstr_dialog_title_medias' => 'メディア表示',
	'boxstr_loading' => '読み込み中',
	'boxstr_next' => '次',
	'boxstr_press_escape_to_close' => '閉じるのに「esc」を押す。',
	'boxstr_previous' => '前',
	'boxstr_slideshowStart' => 'スライドショー',
	'boxstr_slideshowStop' => '停止',
	'boxstr_zoom' => '拡大',

	// E
	'explication_selecteur' => 'ボックスをトリガーする項目のターゲットを指定してください。(CSSの表現または jQueryのスコープ)',
	'explication_selecteur_galerie' => 'ギャラリーにグループ化するアイテムのターゲットを指定してください。(CSSの表現または jQueryのスコープ)',
	'explication_splash_url' => '公開サイトに最初にアクセスした時に、ボックスに自動的に表示されるメディアのURLを指定してください。',
	'explication_traiter_toutes_images' => 'すべての画像にボックスを挿入しますか？',

	// I
	'info_box_lity_nom_skin__simple_dark' => 'ダーク（デフォルト）',
	'info_box_lity_nom_skin__simple_white' => 'ライト（デフォルト）',
	'info_box_lity_nom_skin_fancybox' => 'Fancybox風',
	'info_box_lity_nom_skin_thickbox' => 'Thickbox風',

	// L
	'label_active' => '公開サイトのメディアボックスを有効にする',
	'label_apparence' => '外観',
	'label_aucun_style' => 'デフォルトのスキンを挿入しない',
	'label_choix_transition_elastic' => '弾性',
	'label_choix_transition_fade' => 'クロスフェード',
	'label_choix_transition_none' => 'トランジション効果なし',
	'label_maxheight' => '最大高さ（% または px）',
	'label_maxwidth' => '最大幅（%またはpx）',
	'label_minheight' => 'ミニ高さ（%またはpx）',
	'label_minwidth' => 'ミニ幅（%またはpx）',
	'label_opacite' => '背景の不透明度',
	'label_selecteur_commun' => '原則として',
	'label_selecteur_galerie' => 'ギャラリーで',
	'label_skin' => '視覚的なドレスアップ',
	'label_slideshow_speed' => 'スライドショー写真の露光時間（ミリ秒）',
	'label_speed' => '遷移速度（ミリ秒）',
	'label_splash' => 'スプラッシュボックス',
	'label_splash_height' => '高さ（%またはpx）',
	'label_splash_url' => '表示するURL',
	'label_splash_width' => '幅（%またはpx）',
	'label_traiter_toutes_images' => '画像',
	'label_transition' => '2つのビュー間の遷移',

	// T
	'titre_menu_box' => 'マルチメディアボックス',
	'titre_page_configurer_box' => 'メディアボックスの設定'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_ja.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=ja
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_reinitialiser' => 'リセットする',
	'boxstr_close' => '閉じる',
	'boxstr_current' => '@current@/@total@',
	'boxstr_dialog_title_default' => 'ダイアログボックス',
	'boxstr_dialog_title_medias' => 'メディア表示',
	'boxstr_loading' => '読み込み中',
	'boxstr_next' => '次',
	'boxstr_press_escape_to_close' => '閉じるのに「esc」を押す。',
	'boxstr_previous' => '前',
	'boxstr_slideshowStart' => 'スライドショー',
	'boxstr_slideshowStop' => '停止',
	'boxstr_zoom' => '拡大',

	// E
	'explication_selecteur' => 'ボックスをトリガーする項目のターゲットを指定してください。(CSSの表現または jQueryのスコープ)',
	'explication_selecteur_galerie' => 'ギャラリーにグループ化するアイテムのターゲットを指定してください。(CSSの表現または jQueryのスコープ)',
	'explication_splash_url' => '公開サイトに最初にアクセスした時に、ボックスに自動的に表示されるメディアのURLを指定してください。',
	'explication_traiter_toutes_images' => 'すべての画像にボックスを挿入しますか？',

	// I
	'info_box_lity_nom_skin__simple_dark' => 'ダーク（デフォルト）',
	'info_box_lity_nom_skin__simple_white' => 'ライト（デフォルト）',
	'info_box_lity_nom_skin_fancybox' => 'Fancybox風',
	'info_box_lity_nom_skin_thickbox' => 'Thickbox風',

	// L
	'label_active' => '公開サイトのメディアボックスを有効にする',
	'label_apparence' => '外観',
	'label_aucun_style' => 'デフォルトのスキンを挿入しない',
	'label_choix_transition_elastic' => '弾性',
	'label_choix_transition_fade' => 'クロスフェード',
	'label_choix_transition_none' => 'トランジション効果なし',
	'label_maxheight' => '最大高さ（% または px）',
	'label_maxwidth' => '最大幅（%またはpx）',
	'label_minheight' => 'ミニ高さ（%またはpx）',
	'label_minwidth' => 'ミニ幅（%またはpx）',
	'label_opacite' => '背景の不透明度',
	'label_selecteur_commun' => '原則として',
	'label_selecteur_galerie' => 'ギャラリーで',
	'label_skin' => '視覚的なドレスアップ',
	'label_slideshow_speed' => 'スライドショー写真の露光時間（ミリ秒）',
	'label_speed' => '遷移速度（ミリ秒）',
	'label_splash' => 'スプラッシュボックス',
	'label_splash_height' => '高さ（%またはpx）',
	'label_splash_url' => '表示するURL',
	'label_splash_width' => '幅（%またはpx）',
	'label_traiter_toutes_images' => '画像',
	'label_transition' => '2つのビュー間の遷移',

	// T
	'titre_menu_box' => 'マルチメディアボックス',
	'titre_page_configurer_box' => 'メディアボックスの設定',
];
